==> queen-beecon_1.3.2.tar.gz: queen-beecon-1.3.2/queen-beecon-orientation.h <==
/*
 * This file is a part of Queen Beecon Widget
 * queen-beecon-accelerometer: Utility for QBW Accelerometer Management and Operations
 *
 * http://talk.maemo.org/showthread.php?t=45388
 *
 * Copyright (c) 2010 No!No!No!Yes! (Alessandro Peralma)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version. or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ifndef QUEEN_BEECON_ORIENTATION_H
#define QUEEN_BEECON_ORIENTATION_H

typedef enum {
	QBW_ENABLE_ORIENTATION_MONITOR,
	QBW_READ_ORIENTATION_XYZ,
	QBW_DISABLE_ORIENTATION_MONITOR
} QbwOrientationAction;

// DBUS Management functions
DBusHandlerResult queen_beecon_orientation_filter_function(DBusConnection *connection, DBusMessage *message, QueenBeecon *self);
gboolean queen_beecon_orientation_manager(QueenBeecon *self, QbwOrientationAction action);

#endif /* QUEEN_BEECON_ORIENTATION_H */

==> queen-beecon_1.3.3.tar.gz: queen-beecon-1.3.3/queen-beecon-orientation.h <==
/*
 * This file is a part of Queen Beecon Widget
 * queen-beecon-accelerometer: Utility for QBW Accelerometer Management and Operations
 *
 * http://talk.maemo.org/showthread.php?t=45388
 *
 * Copyright (c) 2010 No!No!No!Yes! (Alessandro Peralma)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version. or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ifndef QUEEN_BEECON_ORIENTATION_H
#define QUEEN_BEECON_ORIENTATION_H

typedef enum {
	QBW_ENABLE_ORIENTATION_MONITOR,
	QBW_READ_ORIENTATION_XYZ,
	QBW_DISABLE_ORIENTATION_MONITOR
} QbwOrientationAction;

// DBUS Management functions
DBusHandlerResult queen_beecon_orientation_filter_function(DBusConnection *connection, DBusMessage *message, QueenBeecon *self);
gboolean queen_beecon_orientation_manager(QueenBeecon *self, QbwOrientationAction action);
#ifdef NOT_WORKING
void set_portrait(GtkWidget *self, char const *prop, guint32 value);
void init_portrait(GtkWidget *win);
void init_landscape(GtkWidget *win);
#endif //NOT_WORKING
#endif /* QUEEN_BEECON_ORIENTATION_H */
